@@ -1,7 +1,10 @@
 class Constants:
     CHANNELS_ITEM_TYPE = "channels"
     IS_DEFAULT = "IsDefault"
+    LIBRARY_NAME_KEY = "library_name"
     NEW_ITEM_NAME_KEY = "new_item_name"
+    PACKAGE_NAME_KEY = "package_name"
+    PACKAGE_VERSION_KEY = "package_version"
     PROJECT_IDS_KEY = "project_ids"
     PROJECT_TRIGGERS_ITEM_TYPE = "projecttriggers"
     RUNBOOKS_ITEM_TYPE = "runbooks"
